<?php
/**
 * Block Name:        Block: Linear listings
 * Description:       A block to show listings.
 * Author:            Oliver Granlund
 * Author URI:        https://olli.works
 */

@require_once 'utils.php';

/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */
add_action( 'init', function() {
	register_block_type( plugin_dir_path( __FILE__ ) . 'build' );
} );

// Globals filter
add_filter( 'linear_listings_block_global_data', function( $string ){
	$config = linear_listings_get_block_config();

	return [
		'texts' => [
			'loadMore'       					=> __("Load more", 'linear'),
			'ListingsPerPage'       			=> __("Listings per page", 'linear'),
			'loadMoreButtonVisibility'  		=> __("\"Load more\"-button visibility", 'linear'),
			'showingLoadMoreButton'     		=> __("Showing \"Load more\"-button", 'linear'),
			'hidingLoadMoreButton'      		=> __("\"Load more\"-button hidden", 'linear'),
			'errorFailedLoadingListings'    	=> __("Oops, error has occurred!<br>If the problem persists, please contact %s", 'linear'),
			'noResultsTitle'    				=> __("No results with set filters", 'linear'),
			'noResultsBody'    					=> __("Unfortunately we couldn't find any results with these filters. Please adjust your filters or reset them all together.", 'linear'),
			'frontendFiltersVisibility'    		=> __("Show listing filters", 'linear'),
			'showingFrontendFilters'    		=> __("Showing filters", 'linear'),
			'hidingFrontendFilters'    			=> __("Listings filters are hidden", 'linear'),
			'productGroup'		    			=> __("Product group", 'linear'),
			'apartments'    					=> __("Apartments", 'linear'),
			'plots'    							=> __("Plots", 'linear'),
			'farms' 				   			=> __("Farms", 'linear'),
			'garages'    						=> __("Garages and parking spaces", 'linear'),
			'vacationApartment'    				=> __("Vacation Apartment", 'linear'),
			'roomCount'			    			=> __("Room count", 'linear'),
			'room'    							=> __("room", 'linear'),
			'rooms'    							=> __("rooms", 'linear'),
			'listingType'    					=> __("Listing Type", 'linear'),
			'flat'    							=> __("Flat", 'linear'),
			'rowhouse'    						=> __("Rowhouse", 'linear'),
			'pairhouse'    						=> __("Pairhouse", 'linear'),
			'detachedHouse'    					=> __("Detached House", 'linear'),
			'sauna'    							=> __("Sauna", 'linear'),
			'balcony'  		  					=> __("Balcony", 'linear'),
			'elevator'   	 					=> __("Elevator", 'linear'),
			'setFilterMinimumPrice'				=> __("Set filter minimum price", 'linear'),
			'setFilterMaximumPrice'				=> __("Set filter maximum price", 'linear'),
			'setFilterMinimumRent'    			=> __("Set filter minimum rent", 'linear'),
			'setFilterMaximumRent'    			=> __("Set filter maximum rent", 'linear'),
			'businessListingType'    			=> __("Business Listing Type", 'linear'),
			'officeSpace'    					=> __("Office Space", 'linear'),
			'businessSpace'    					=> __("Business Space", 'linear'),
			'productionSpace'    				=> __("Production Space", 'linear'),
			'storageSpaceHouse'					=> __("Storage Space House", 'linear'),
			'sort'								=> __("Sort", 'linear'),
			'latestFirst'						=> __("Latest first", 'linear'),
			'oldestFirst'						=> __("Oldest first", 'linear'),
			'showFilters'						=> __("Show filters", 'linear'),
			'hideFilters'						=> __("Hide filters", 'linear'),
			'resetFilters'						=> __("Reset filters", 'linear'),
			'frontendRangeSlidersVisibility'	=> __("Show additional range filters eg. price", 'linear'),
			'showingRangeFilters'				=> __("Showing range filters", 'linear'),
			'hidingRangeFilters'				=> __("Range filters hidden", 'linear'),
			'noListingsTitle'					=> __("No results", 'linear'),
			'noListingsBody'					=> __("Unfortunately there are currently no results to show. Come back later to see if any have been added!", 'linear'),
			'frontendOrderByVisibility'			=> __("Show 'Sort by' ordering", 'linear'),
			'showingOrderBy'					=> __("Showing ordering options", 'linear'),
			'hidingOrderBy'						=> __("Ordering options hidden", 'linear'),
			'chooseLocation'					=> __("Choose location", 'linear'),
			'boolFalse'							=> _x("No", 'boolFalse', 'linear'),
			'boolTrue'							=> _x("Yes", 'boolTrue', 'linear'),
			'bidding'							=> __("Bidding", 'linear')
		],
		'actions' => $config["actions"],
		'restBase' => site_url( 'wp-json' ),
		'apiVersion' => apply_filters('linear_get_api_version', ''),
		'blockClassName' => $config["blockClassName"],
		'colors' => apply_filters('linear_get_colors', ''),
		'searchOptions' => apply_filters('linear_get_search_options', '')
	];
}, 10, 1 );

/**
 * Enqueue the frontend scripts required by the block.
 * Only load them if the page contains our block.
 */
function linear_listings_block_enqueue_frontend_assets() {
	$metadata = linear_listings_get_block_metadata();

	if( isset($metadata) ){
		if ( !has_block($metadata['name']) ) {
			return;
		}
	}

	$config = linear_listings_get_block_config();

	// Register our frontend script with dependencies.
	wp_enqueue_script(
		$config["frontend"]["handleJS"],
		plugins_url("build-frontend/index.js", __FILE__),
		$config["frontend"]["dependencies"],
		null
	);

	// Pass PHP configuration to our frontend script.
	wp_localize_script(
		$config["frontend"]["handleJS"],
		$config["frontend"]["globalConfig"],
		apply_filters('linear_listings_block_global_data', null)
	);
}

add_action( 'enqueue_block_assets', 'linear_listings_block_enqueue_frontend_assets' );

// Force globals in WP-Admin
add_action( 'admin_head', function() {
	$config = linear_listings_get_block_config();
	$globalConfig = $config["frontend"]["globalConfig"];
	$globalData = apply_filters('linear_listings_block_global_data', null);

	// Start buffer
	ob_start();

		?><script type="text/javascript">
			window.<?= $globalConfig ?> = <?= json_encode($globalData) ?>;
		</script><?php

	// Output globals
	echo ob_get_clean();
} );

// For adding block outside of Gutenberg, could be optimized
add_shortcode( 'linear_block_listings', function( $atts ){

	// Setup args
	$args = shortcode_atts([
		'type' => 'all', // Types: all, APARTMENTS, RENT_APARTMENT, BUSINESS_PREMISES
		'per_page' => '8',
		'filters' => 'true',
		'loadmore' => 'true',
		'classes' => '',
		'range_sliders' => 'true',
		'order_by' => 'true',
	], $atts );

	// Mappings for more user friendly usage
	$value_mappings = [
		'all' => 'all',
		'apartments' => 'APARTMENTS',
		'rent_apartments' => 'RENT_APARTMENT',
		'business_premises' => 'BUSINESS_PREMISES'
	];

	$config = linear_listings_get_block_config();

	// Register our frontend script with dependencies.
	wp_enqueue_script(
		$config["frontend"]["handleJS"],
		plugins_url("build-frontend/index.js", __FILE__),
		$config["frontend"]["dependencies"],
		null
	);

	wp_enqueue_style(
	  	$config["frontend"]["handleCSS"],
	    plugins_url("build/style-index.css", __FILE__)
	);

	// Pass PHP configuration to our frontend script, disabled for now.
	// wp_localize_script(
	//   	$config["frontend"]["handleJS"],
	//  	$config["frontend"]["globalConfig"],
	// 	    apply_filters('linear_listings_block_global_data', null)
	// );

	ob_start();
 
		// Adding in globals in such a way that caching plugins cannot affect it
		echo '<script id="block-linear-listings-frontend.js-js-extra">
			if( typeof blockLinearListingsConfig === "undefined"){
				var blockLinearListingsConfig = ' . json_encode( apply_filters('linear_listings_block_global_data', null) ) . '
			}
		</script>';
		?>
			<div class="wp-block-linear-listings linear-listings is-style-wide <?php echo $args['classes'] ?>" 
				data-listings-type="<?php echo $value_mappings[ $args['type'] ] ?>" 
				data-listings-per-page="<?php echo $args['per_page'] ?>" 
				data-show-load-more="<?php echo $args['loadmore'] ?>"
				data-show-filters="<?php echo $args['filters'] ?>"
				data-show-range-sliders="<?php echo $args['range_sliders'] ?>"
				data-show-order-by="<?php echo $args['order_by'] ?>" 
			></div>
		<?php

    return ob_get_clean();
} );
