<?php
/**
 * Fetching content from api functionality
 *
 * @package Linear
 */

/**
 * Endpoints for Gutenberg blocks
 */
class Linear_Endpoints {

	protected static $linear;
    protected $linear_middleware;
    protected $api_key;

	public function __construct() {
		if ( is_null( self::$linear ) ) {
			self::$linear = Linear::get_instance();
		}

        $this->linear_middleware 	= self::$linear->get_middleware();
		$this->api_version 			= ( self::$linear->get_option( 'api_key' ) ? 'v2' : 'v1' );

        add_action( 'rest_api_init', function(){	
			
			$endpoints = [
				'all' => 'get_all',
				'apartments' => 'get_apartments',
				'rentals' => 'get_rentals',
				'business_premises' => 'get_business_premises',
			];

			foreach( $endpoints as $endpoint => $callback ){
				register_rest_route( 'linear/' . $this->api_version, '/listings/' . $endpoint,
					[
						'methods' 				=> 'GET',
						'callback' 				=> [ $this, $callback ],
						'permission_callback' 	=> function( $request ){
							return true;
						},
					]
				);
			}


			register_rest_route( 'linear/' . $this->api_version, '/listing/(?P<id>.+)',
				[
					'methods' 				=> 'GET',
					'callback' 				=> [ $this, 'get_single' ],
					'permission_callback' 	=> function( $request ){
						return true;
					},
				]
			);
		} );
	}

    public function get_all( \WP_REST_Request $request ) {

		$api_response = $this->linear_middleware->get_all();

		// API/Transient response
		return new \WP_REST_Response( $api_response, 200 );
	}

    public function get_apartments( \WP_REST_Request $request ) {

		$api_response = $this->linear_middleware->get_all_by_type( 'APARTMENTS' );

		// API/Transient response
		return new \WP_REST_Response( $api_response, 200 );
	}

    public function get_rentals( \WP_REST_Request $request ) {

		$api_response = $this->linear_middleware->get_all_by_type( 'RENT_APARTMENT' );

		// API/Transient response
		return new \WP_REST_Response( $api_response, 200 );
	}

    public function get_business_premises( \WP_REST_Request $request ) {

		$api_response = $this->linear_middleware->get_all_by_type( 'BUSINESS_PREMISEs' );

		// API/Transient response
		return new \WP_REST_Response( $api_response, 200 );
	}

	public function get_single( \WP_REST_Request $request ) {

		$params = $request->get_params();

		if( !isset( $params['id'] ) ){
			return $this->return_error_invalid_id();
		}

		$id = sanitize_title( $params['id'] );

		// validate title contents
		if( strlen( $id ) !== 36 || substr_count( $id, "-" ) !== 4 ){
			return $this->return_error_invalid_id();
		}

		$api_response = $this->linear_middleware->get_single( $id );

		return new \WP_REST_Response( $api_response, 200 );
	}

    private function return_error_invalid() {
		return new \WP_REST_Response(array('error' => 'Invalid input.'), 400);
	}

    private function return_error_invalid_id() {
		return new \WP_REST_Response(array('error' => 'Invalid id.'), 400);
	}

	private function return_error_duplicate() {
		return new \WP_REST_Response(array('error' => 'Cannot use the same "from" and "to" values.'), 400);
	}

	private function return_error_empty() {
		return new \WP_REST_Response(array('error' => 'No results for chosen route.'), 200);
	}

	private function return_error_api() {
		return new \WP_Error('error', 'API error');
	}
}