<?php 

/**
 * Handles custom sitemap for listings
 */
class Linear_Sitemaps extends WP_Sitemaps_Provider {
	public $name;
	public function __construct() {

		$this->name        = 'listings';
		$this->object_type = 'listings';

		$this->yoast_exception();
		$this->seopress_exception();
		$this->the_seo_framework_exception();
	}

	public function get_url_list( $page_num, $subtype = '' ) {

		$listings = apply_filters( "linear_listings_all", null );

		$url_list = array();

		foreach ( $listings as $listing ) {
			$sitemap_entry = [
				'loc' => $listing['permalink']
			];

			$url_list[] = $sitemap_entry;
		}

		return $url_list;
	}

	public function get_max_num_pages( $subtype = '' ) {
		return 1;
	}

    public function register_sitemap_provider() {
		$provider = new Linear_Sitemaps();
		wp_register_sitemap_provider( $provider->name, $provider );
	}

	private function yoast_exception(){
		add_filter( 'wpseo_sitemap_index', function( $sitemap_custom_items ){

			$listings = apply_filters( "linear_listings_all", null );

			if( $listings ){
				foreach ( $listings as $listing ) {
					$sitemap_custom_items .= '
						<sitemap>
							<loc>' . $listing['permalink'] . '</loc>
						</sitemap>';
				}	
			}
			
			return $sitemap_custom_items;

		} );
	}

	private function seopress_exception(){
		add_filter('seopress_sitemaps_external_link', function( $custom_sitemap = [] ) {

			$listings = apply_filters( "linear_listings_all", null );

			if( $listings ){
				foreach ( $listings as $listing ) {
					$custom_sitemap[] = [
						'sitemap_url' 		=> $listing['permalink']
					];
				}	
			}

			return $custom_sitemap;

		});
	}

	private function the_seo_framework_exception(){
		add_filter( 'the_seo_framework_sitemap_additional_urls', function( $custom_urls = [] ) {

			$listings = apply_filters( "linear_listings_all", null );

			if( $listings ){
				foreach ( $listings as $listing ) {
					$custom_urls[ $listing['permalink'] ] = [
						'lastmod' => null,
					];
				}	
			}
		
			return $custom_urls;
		} );
	}

}